from setuptools import setup

setup(
    name="mypackage01",
    version="0.1",
    description="My Python package",
    author="sai kumar sapa",
    author_email="saikumarsapa@gmail.com",
    packages=["pythonlib"],
)